@@ -4,11 +4,10 @@ use strict;
 use warnings;
 use Carp;
 use POE::Filter::IRCD;
-use File::Basename ();
+use File::Basename qw(fileparse);
 use base qw(POE::Filter);
-use vars qw($VERSION);
 
-$VERSION = '1.4';
+our $VERSION = '1.4';
 
 sub new {
     my ($package, %params) = @_;
@@ -82,7 +81,7 @@ sub debug {
 
 sub chantypes {
     my ($self, $ref) = @_;
-    return if ref $ref ne 'ARRAY' || !scalar @{ $ref };
+    return if ref $ref ne 'ARRAY' || !@{ $ref };
     $self->{chantypes} = $ref;
     return 1;
 }
@@ -223,7 +222,7 @@ sub _get_ctcp {
                 last CTCP;
             }
             $file =~ s/^"|"$//g;
-            $file = File::Basename::fileparse($file);
+            $file = fileparse($file);
                 
             push @$events, {
                 name => 'dcc_request',
@@ -260,7 +259,7 @@ sub _get_ctcp {
         }
     }
 
-    if ($text && scalar @$text) {
+    if ($text && @$text) {
         my $what;
         ($what) = $line =~ /^(:\S+ +\w+ +\S+ +)/
             or warn "What the heck? '$line'\n" if $self->{debug};
@@ -327,52 +326,42 @@ generic.
 
 =head1 CONSTRUCTOR
 
-=over
-
-=item C<new>
+=head2 C<new>
 
 Returns a POE::Filter::IRC::Compat object.
 
-=back
-
 =head1 METHODS
 
-=over
-
-=item C<get>
+=head2 C<get>
 
 Takes an arrayref of L<POE::Filter::IRCD> hashrefs and produces an arrayref of
 L<POE::Component::IRC|POE::Component::IRC> compatible event hashrefs. Yay.
 
-=item C<get_one_start>
-
-=item C<get_one>
+=head2 C<get_one_start>, C<get_one>
 
 These perform a similar function as C<get()> but enable the filter to work with
 L<POE::Filter::Stackable|POE::Filter::Stackable>.
 
-=item C<chantypes>
+=head2 C<chantypes>
 
 Takes an arrayref of possible channel prefix indicators.
 
-=item C<debug>
+=head2 C<debug>
 
 Takes a true/false value which enables/disables debugging accordingly.
 Returns the debug status.
 
-=item C<clone>
+=head2 C<clone>
 
 Makes a copy of the filter, and clears the copy's buffer.
 
-=item C<put>
+=head2 C<put>
 
 Takes an array reference of CTCP messages to be properly quoted. This
 doesn't support CTCPs embedded in normal messages, which is a
 brain-dead hack in the protocol, so do it yourself if you really need
 it. Returns an array reference of the quoted lines for sending.
 
-=back
-
 =head1 AUTHOR
 
 Chris 'BinGOs' Williams
